@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QUrl>
 #include <QImageWriter>
 #include <QMimeDatabase>
+#include <QDebug>
 
 // KDE
 #include <QFileDialog>
@@ -254,8 +255,8 @@ GvCore::GvCore(MainWindow* mainWindow, SortedDirModel* dirModel)
     d->q = this;
     d->mMainWindow = mainWindow;
     d->mDirModel = dirModel;
-    d->mRecentFoldersModel = 0;
-    d->mRecentFilesModel = 0;
+    d->mRecentFoldersModel = nullptr;
+    d->mRecentFilesModel = nullptr;
 
     d->setupPalettes();
 
@@ -365,7 +366,7 @@ void GvCore::saveAs(const QUrl &url)
     KJob* job = doc->save(saveAsUrl, format.data());
     if (!job) {
         const QString name = saveAsUrl.fileName().isEmpty() ? saveAsUrl.toDisplayString() : saveAsUrl.fileName();
-        const QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br />%2",
+        const QString msg = xi18nc("@info", "<emphasis strong='true'>Saving <filename>%1</filename> failed:</emphasis><nl />%2",
                                    name, doc->errorString());
         KMessageBox::sorry(QApplication::activeWindow(), msg);
     } else {
@@ -388,8 +389,8 @@ void GvCore::slotSaveResult(KJob* _job)
 
     if (job->error()) {
         QString name = newUrl.fileName().isEmpty() ? newUrl.toDisplayString() : newUrl.fileName();
-        QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br />%2",
-                             name, kxi18n(qPrintable(job->errorString())));
+        const QString msg = xi18nc("@info", "<emphasis strong='true'>Saving <filename>%1</filename> failed:</emphasis><nl />%2",
+                                   name, kxi18n(qPrintable(job->errorString())));
 
         int result = KMessageBox::warningContinueCancel(
                          d->mMainWindow, msg,
