@@ -24,9 +24,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gwenviewlib_export.h>
 
 // Qt
+#include <QDialog>
 
 // KDE
-#include <KDialog>
 
 // Local
 
@@ -34,11 +34,11 @@ namespace Gwenview
 {
 
 struct ResizeImageDialogPrivate;
-class GWENVIEWLIB_EXPORT ResizeImageDialog : public KDialog
+class GWENVIEWLIB_EXPORT ResizeImageDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ResizeImageDialog(QWidget *parent);
+    explicit ResizeImageDialog(QWidget *parent);
     ~ResizeImageDialog();
 
     void setOriginalSize(const QSize&);
@@ -47,6 +47,8 @@ public:
 private Q_SLOTS:
     void slotWidthChanged(int);
     void slotHeightChanged(int);
+    void slotWidthPercentChanged(double);
+    void slotHeightPercentChanged(double);
     void slotKeepAspectChanged(bool);
 
 private:
